﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace Kong.SyntaxHighlighter.Winform
{
    public partial class SettingsForm : Form
    {
        public SettingsForm()
        {
            InitializeComponent();

            Load += SettingsForm_Load;
        }

        void SettingsForm_Load(object sender, EventArgs e)
        {
            var settings = Settings.Default;

            SetTextBoxColor(BorderColorTextBox, settings.BorderColor);
            SetTextBoxColor(BackColorTextBox, settings.BackgroundColor);

            EnableAltLineCheckBox.Checked = settings.EnableAltLine;
            SetTextBoxColor(LineColorTextBox, settings.LineColor);
            SetTextBoxColor(AltLineColorTextBox, settings.AltLineColor);
        }

        private void SetTextBoxColor(TextBox textBox, Color color)
        {
            textBox.BackColor = color;
            textBox.Text = color.ToHexString();
        }

        private void PickColor(TextBox textBox)
        {
            colorDialog1.Color = textBox.BackColor;
            if(colorDialog1.ShowDialog() == DialogResult.OK)
            {
                SetTextBoxColor(textBox, colorDialog1.Color);
            }
        }

        private void ConfirmButton_Click(object sender, EventArgs e)
        {
            var settings = Settings.Default;
            settings.BorderColor = BorderColorTextBox.BackColor;
            settings.BackgroundColor = BackColorTextBox.BackColor;

            settings.EnableAltLine = EnableAltLineCheckBox.Checked;
            settings.LineColor = LineColorTextBox.BackColor;
            settings.AltLineColor = AltLineColorTextBox.BackColor;
            settings.Save();
            DialogResult = DialogResult.OK;
        }

        private void CancelButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
        }

        private void EnableAltLineCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            AltLineColorTextBox.Enabled = EnableAltLineCheckBox.Checked;
        }

        private void BoderColorButton_Click(object sender, EventArgs e)
        {
            PickColor(BorderColorTextBox);
        }

        private void BackColorButton_Click(object sender, EventArgs e)
        {
            PickColor(BackColorTextBox);
        }

        private void LineColorButton_Click(object sender, EventArgs e)
        {
            PickColor(LineColorTextBox);
        }

        private void AltLineColorButton_Click(object sender, EventArgs e)
        {
            PickColor(AltLineColorTextBox);
        }
    }

    public static class ColorExtensions
    {
        public static string ToHexString(this Color color)
        {
            return "#" + String.Format("{0:X}", color.ToArgb()).Substring(2);   
        }
    }
}
